@@ -2,6 +2,7 @@ import aio_pika
 from aio_pika.pool import Pool
 from aio_pika import Channel, Message
 from aio_pika.abc import AbstractRobustConnection
+from aio_pika.exceptions import AMQPConnectionError
 
 from .broker_handler import BaseModel, BrokerHandler, T, RequestType
 from .grpc_client import GRPCClient
@@ -15,6 +16,7 @@ from pydantic.error_wrappers import ValidationError
 from typing import Any, Type, Union
 
 import logging
+
 logging.basicConfig(level=logging.INFO)
 
 
@@ -57,11 +59,13 @@ class RabbitMQHandler(BrokerHandler):
 
         assert self._read_queue_name or self._write_queue_name, "No queues were passed"
 
-    async def __init_pools(self):
+    async def __init_pools(self) -> bool:
         self._connection_pool = Pool(self.__get_connection, max_size=self._max_connections, loop=self._loop)
         self._channel_pool = Pool(self.__get_channel, max_size=self._max_channels, loop=self._loop)
 
-    async def __init_queues(self):
+        return True
+
+    async def __init_queues(self) -> bool:
         for _ in range(self._max_channels):
             async with self._channel_pool.acquire() as channel:
                 if self._read_queue_name:
@@ -71,17 +75,31 @@ class RabbitMQHandler(BrokerHandler):
                 if self._callback_queue_name:
                     await channel.declare_queue(self._callback_queue_name)
 
-    async def init_connection_and_queue_pools(self):
-        await self.__init_pools()
-        await self.__init_queues()
+        return True
+
+    async def prepare_handler(self):
+        pools, queues = False, False
+
+        pools = await self.__init_pools()
+        if pools:
+            queues = await self.__init_queues()
+
+        return pools and queues
 
     async def __get_connection(self) -> AbstractRobustConnection:
-        return await aio_pika.connect_robust(
-            host=self._host,
-            login=self._login,
-            password=self._password,
-            port=self._port
-        )
+        try:
+            while True:
+                connection = await aio_pika.connect_robust(
+                    host=self._host,
+                    login=self._login,
+                    password=self._password,
+                    port=self._port
+                )
+
+                return connection
+        except AMQPConnectionError:
+            logging.error("Failed to connect to RabbitMQ. Retrying in 5 sec.")
+            await asyncio.sleep(5)
 
     async def __get_channel(self) -> Channel:
         async with self._connection_pool.acquire() as connection:
@@ -92,7 +110,7 @@ class RabbitMQHandler(BrokerHandler):
             raise NoReadQueueException("No read queue")
 
         async with self._channel_pool.acquire() as channel:
-            queue = await channel.declare_queue(self._read_queue_name)
+            queue = await channel.get_queue(self._read_queue_name)
             async with queue.iterator() as queue_iter:
                 async for message in queue_iter:
                     async with message.process():
@@ -116,7 +134,7 @@ class RabbitMQHandler(BrokerHandler):
         async with self._channel_pool.acquire() as channel:
             # TODO: Либо передавать название очереди как параметр и отправлять через `routing_key`,
             #  а не в конкретную очередь
-            queue = channel.get_queue(self._write_queue_name)
+            queue = await channel.get_queue(self._write_queue_name)
             message = Message(body=message_body)
             await queue.publish(message)
 
